from django.contrib.auth import get_user_model
from django.db import models


User = get_user_model()


class OdooUser(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE)
    odoo_id = models.BigIntegerField(primary_key=True)



from django.conf import settings


ODOO_SERVER_URL = getattr(settings, 'ODOO_SERVER_URL', 'http://localhost')
ODOO_SERVER_PORT = getattr(settings, 'ODOO_SERVER_PORT', None)
ODOO_SERVER_DBNAME = getattr(settings, 'ODOO_SERVER_DBNAME', 'demo')



# Generated by Django 3.2.5 on 2021-07-08 11:21

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='OdooUser',
            fields=[
                ('odoo_id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from xmlrpc.client import ServerProxy as XmlrpcServerProxy

from django.contrib.auth.backends import BaseBackend

from . import settings
from .models import OdooUser, User


class OdooBackend(BaseBackend):
    def __init__(self):
        url = settings.ODOO_SERVER_URL
        if settings.ODOO_SERVER_PORT is not None:
            url += f':{settings.ODOO_SERVER_PORT}'
        url_login = f'{url}/xmlrpc/2/common'
        self.ODOO_SOCK_COMMON = XmlrpcServerProxy(url_login)

    def authenticate(self, request, username=None, password=None):
        user = User.objects.filter(username=username).first()
        if user:
            return user if user.check_password(password) else None

        user_uid = self.ODOO_SOCK_COMMON.authenticate(
            settings.ODOO_SERVER_DBNAME,
            username,
            password,
            {},
        )
        if user_uid is None:
            return None

        user.set_password(password)
        user.save()

        OdooUser.objects.create(odoo_id=user_uid, user=user)
        return user

    def get_user(self, user_id):
        try:
            return User.objects.get(pk=user_id)
        except User.DoesNotExist:
            return None



from os import path

from setuptools import setup


this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='django-odoo-auth',
    version='1.0.3.1',
    packages=['odoo_auth', 'odoo_auth.migrations'],
    license='Apache-2.0 License',
    description='Custom django auth backend for authorization via odoo',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/w0rng/django-odoo-auth',
    author='w0rng, Julien DRECQ',
    install_requires=[
        'django',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
